@@ -68,7 +68,7 @@ class Exceptions:
 
 class HealthLakeClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/healthlake.html#HealthLake.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/healthlake.html#HealthLake.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_healthlake/client.html)
     """
 
@@ -84,7 +84,7 @@ class HealthLakeClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/healthlake.html#HealthLake.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/healthlake.html#HealthLake.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_healthlake/client.html#can_paginate)
         """
 
@@ -92,38 +92,38 @@ class HealthLakeClient(BaseClient):
         self,
         *,
         DatastoreTypeVersion: Literal["R4"],
-        DatastoreName: str = None,
-        SseConfiguration: "SseConfigurationTypeDef" = None,
-        PreloadDataConfig: "PreloadDataConfigTypeDef" = None,
-        ClientToken: str = None,
-        Tags: Sequence["TagTypeDef"] = None
+        DatastoreName: str = ...,
+        SseConfiguration: "SseConfigurationTypeDef" = ...,
+        PreloadDataConfig: "PreloadDataConfigTypeDef" = ...,
+        ClientToken: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateFHIRDatastoreResponseTypeDef:
         """
         Creates a Data Store that can ingest and export FHIR formatted data.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/healthlake.html#HealthLake.Client.create_fhir_datastore)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/healthlake.html#HealthLake.Client.create_fhir_datastore)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_healthlake/client.html#create_fhir_datastore)
         """
 
     def delete_fhir_datastore(
-        self, *, DatastoreId: str = None
+        self, *, DatastoreId: str = ...
     ) -> DeleteFHIRDatastoreResponseTypeDef:
         """
         Deletes a Data Store.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/healthlake.html#HealthLake.Client.delete_fhir_datastore)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/healthlake.html#HealthLake.Client.delete_fhir_datastore)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_healthlake/client.html#delete_fhir_datastore)
         """
 
     def describe_fhir_datastore(
-        self, *, DatastoreId: str = None
+        self, *, DatastoreId: str = ...
     ) -> DescribeFHIRDatastoreResponseTypeDef:
         """
         Gets the properties associated with the FHIR Data Store, including the Data
         Store ID, Data Store ARN, Data Store name, Data Store status, created at, Data
         Store type version, and Data Store endpoint.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/healthlake.html#HealthLake.Client.describe_fhir_datastore)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/healthlake.html#HealthLake.Client.describe_fhir_datastore)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_healthlake/client.html#describe_fhir_datastore)
         """
 
@@ -134,7 +134,7 @@ class HealthLakeClient(BaseClient):
         Displays the properties of a FHIR export job, including the ID, ARN, name, and
         the status of the job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/healthlake.html#HealthLake.Client.describe_fhir_export_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/healthlake.html#HealthLake.Client.describe_fhir_export_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_healthlake/client.html#describe_fhir_export_job)
         """
 
@@ -145,36 +145,32 @@ class HealthLakeClient(BaseClient):
         Displays the properties of a FHIR import job, including the ID, ARN, name, and
         the status of the job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/healthlake.html#HealthLake.Client.describe_fhir_import_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/healthlake.html#HealthLake.Client.describe_fhir_import_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_healthlake/client.html#describe_fhir_import_job)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/healthlake.html#HealthLake.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/healthlake.html#HealthLake.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_healthlake/client.html#generate_presigned_url)
         """
 
     def list_fhir_datastores(
-        self,
-        *,
-        Filter: "DatastoreFilterTypeDef" = None,
-        NextToken: str = None,
-        MaxResults: int = None
+        self, *, Filter: "DatastoreFilterTypeDef" = ..., NextToken: str = ..., MaxResults: int = ...
     ) -> ListFHIRDatastoresResponseTypeDef:
         """
         Lists all FHIR Data Stores that are in the user’s account, regardless of Data
         Store status.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/healthlake.html#HealthLake.Client.list_fhir_datastores)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/healthlake.html#HealthLake.Client.list_fhir_datastores)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_healthlake/client.html#list_fhir_datastores)
         """
 
@@ -182,17 +178,17 @@ class HealthLakeClient(BaseClient):
         self,
         *,
         DatastoreId: str,
-        NextToken: str = None,
-        MaxResults: int = None,
-        JobName: str = None,
-        JobStatus: JobStatusType = None,
-        SubmittedBefore: Union[datetime, str] = None,
-        SubmittedAfter: Union[datetime, str] = None
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        JobName: str = ...,
+        JobStatus: JobStatusType = ...,
+        SubmittedBefore: Union[datetime, str] = ...,
+        SubmittedAfter: Union[datetime, str] = ...
     ) -> ListFHIRExportJobsResponseTypeDef:
         """
         Lists all FHIR export jobs associated with an account and their statuses.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/healthlake.html#HealthLake.Client.list_fhir_export_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/healthlake.html#HealthLake.Client.list_fhir_export_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_healthlake/client.html#list_fhir_export_jobs)
         """
 
@@ -200,17 +196,17 @@ class HealthLakeClient(BaseClient):
         self,
         *,
         DatastoreId: str,
-        NextToken: str = None,
-        MaxResults: int = None,
-        JobName: str = None,
-        JobStatus: JobStatusType = None,
-        SubmittedBefore: Union[datetime, str] = None,
-        SubmittedAfter: Union[datetime, str] = None
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        JobName: str = ...,
+        JobStatus: JobStatusType = ...,
+        SubmittedBefore: Union[datetime, str] = ...,
+        SubmittedAfter: Union[datetime, str] = ...
     ) -> ListFHIRImportJobsResponseTypeDef:
         """
         Lists all FHIR import jobs associated with an account and their statuses.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/healthlake.html#HealthLake.Client.list_fhir_import_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/healthlake.html#HealthLake.Client.list_fhir_import_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_healthlake/client.html#list_fhir_import_jobs)
         """
 
@@ -218,7 +214,7 @@ class HealthLakeClient(BaseClient):
         """
         Returns a list of all existing tags associated with a Data Store.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/healthlake.html#HealthLake.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/healthlake.html#HealthLake.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_healthlake/client.html#list_tags_for_resource)
         """
 
@@ -229,12 +225,12 @@ class HealthLakeClient(BaseClient):
         DatastoreId: str,
         DataAccessRoleArn: str,
         ClientToken: str,
-        JobName: str = None
+        JobName: str = ...
     ) -> StartFHIRExportJobResponseTypeDef:
         """
         Begins a FHIR export job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/healthlake.html#HealthLake.Client.start_fhir_export_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/healthlake.html#HealthLake.Client.start_fhir_export_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_healthlake/client.html#start_fhir_export_job)
         """
 
@@ -246,12 +242,12 @@ class HealthLakeClient(BaseClient):
         DatastoreId: str,
         DataAccessRoleArn: str,
         ClientToken: str,
-        JobName: str = None
+        JobName: str = ...
     ) -> StartFHIRImportJobResponseTypeDef:
         """
         Begins a FHIR Import job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/healthlake.html#HealthLake.Client.start_fhir_import_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/healthlake.html#HealthLake.Client.start_fhir_import_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_healthlake/client.html#start_fhir_import_job)
         """
 
@@ -259,7 +255,7 @@ class HealthLakeClient(BaseClient):
         """
         Adds a user specifed key and value tag to a Data Store.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/healthlake.html#HealthLake.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/healthlake.html#HealthLake.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_healthlake/client.html#tag_resource)
         """
 
@@ -267,6 +263,6 @@ class HealthLakeClient(BaseClient):
         """
         Removes tags from a Data Store.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/healthlake.html#HealthLake.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.55/reference/services/healthlake.html#HealthLake.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_healthlake/client.html#untag_resource)
         """
